const router = require('express').Router();
const cosmeticsServices = require('../services/cosmeticsServices');

const { isAuth } = require('../middleware/authMiddleware');

router.get('/catalog', async (req, res) => {
    let cosmetics = await cosmeticsServices.getAll();
    res.render('cosmetics/catalog', {cosmetics});
});

router.get('/add-product', (req, res) => {
    res.render('cosmetics/create')
});

router.post('/add-product', isAuth, async (req, res) => {
    try {
        await cosmeticsServices.create({ ...req.body, owner: req.user._id });
        res.redirect('/cosmetics/catalog');
    } catch (error) {
        console.log(error);
        res.render('cosmetics/create', { error: getErrorMessage(error) });
    }
});

function getErrorMessage(error) {
    let errorsArr = Object.keys(error.errors);

    if (errorsArr.length > 0) {
        return error.errors[errorsArr[0]];
    } else {
        return error.message
    }

}

router.get('/:id/details', async (req, res) => {
    let cosmetics = await cosmeticsServices.getOne(req.params.id);
    let cosmeticsData = await cosmetics.toObject();
    let recCount = cosmeticsData.recommend.length

    let isOwner = cosmeticsData.owner == req.user?._id;
    let cosmeticsOwner = await cosmeticsServices.findOwner(cosmetics.owner).lean();

    let recommended = cosmetics.getRecommend();
    let isRecommended = req.user && recommended.some(c => c._id == req.user?._id);

    res.render('cosmetics/details', { ...cosmeticsData, isOwner, isRecommended, cosmeticsOwner, recCount })
});

async function isOwner(req, res, next) {
    let cosmetics = await cosmeticsServices.getOne(req.params.id);

    if (cosmetics.owner == req.user._id) {
        res.redirect(`/cosmetics/${req.params.id}/details`);
    } else {
        next();
    }
}

async function checkIsOwner(req, res, next) {
    let cosmetics = await cosmeticsServices.getOne(req.params.id);

    if (cosmetics.owner == req.user._id) {
        next();
    } else {
        res.redirect(`/cosmetics/${req.params.id}/details`);
    }
};

router.get('/:id/delete', checkIsOwner, async (req, res) => {
    try {
        await cosmeticsServices.delete(req.params.id);

        res.redirect('/cosmetics/catalog');
    } catch (error) {
        res.render('cosmetics/create', { error: getErrorMessage(error) });
    }

});

router.get('/:id/edit', async (req, res) => {
    let cosmetics = await cosmeticsServices.getOne(req.params.id);
    res.render('cosmetics/edit', { ...cosmetics.toObject() })
});

router.post('/:id/edit', checkIsOwner, async (req, res) => {
    try {
        console.log(await cosmeticsServices.updateOne(req.params.id, req.body));

        res.redirect(`/cosmetics/${req.params.id}/details`);
    } catch(error) {
        console.log(getErrorMessage(error));
        res.render('cosmetics/create', { error: getErrorMessage(error) });
    }

});

router.get('/:id/recommend', isOwner, async (req, res) => {
    let cosmetics = await cosmeticsServices.getOne(req.params.id);

    cosmetics.recommend.push(req.user);
    await cosmetics.save();

    res.redirect(`/cosmetics/${req.params.id}/details`);

});

module.exports = router;